/**
  EasyVR
  SonicNet Demo (Slave)

  Simple demo showing the SonicNet feature of the EasyVR 3.
  
  The code is compatible with older EasyVR 2.0 modules.

  The module waits for a SonicNet token from an external source, then it reacts
  accordingly by moving the servo connected to pin 9 or by switching ON/OFF
  the LED using pin IO1 of EasyVR.
  
  Tokens 1 to 4 can be sent from the PC running the latest EasyVR Commander or
  by using the included demo Android App on your smartphone or tablet.

**
  Example code for the EasyVR library v1.8
  Written in 2016 by RoboTech srl for VeeaR <http:://www.veear.eu>

  To the extent possible under law, the author(s) have dedicated all
  copyright and related and neighboring rights to this software to the
  public domain worldwide. This software is distributed without any warranty.

  You should have received a copy of the CC0 Public Domain Dedication
  along with this software.
  If not, see <http://creativecommons.org/publicdomain/zero/1.0/>.
*/

#include "Arduino.h"
#if !defined(SERIAL_PORT_MONITOR)
  #error "Arduino version not supported. Please update your IDE to the latest version."
#endif

#if defined(SERIAL_PORT_USBVIRTUAL)
  // Shield Jumper on HW (for Leonardo and Due)
  #define port SERIAL_PORT_HARDWARE
  #define pcSerial SERIAL_PORT_USBVIRTUAL
#else
  // Shield Jumper on SW (using pins 12/13 or 8/9 as RX/TX)
  #include "SoftwareSerial.h"
  SoftwareSerial port(12, 13);
  #define pcSerial SERIAL_PORT_MONITOR
#endif

#include "EasyVR.h"

EasyVR easyvr(port);

#include <Servo.h>
Servo myservo;

int8_t bits = 4;
int8_t servo_pos = 2;
int8_t idx = 0;

void setup()
{
  // setup PC serial port
  pcSerial.begin(9600);

  // bridge mode?
  int mode = easyvr.bridgeRequested(pcSerial);
  switch (mode)
  {
  case EasyVR::BRIDGE_NONE:
    // setup EasyVR serial port
    port.begin(9600);
    // run normally
    pcSerial.println(F("---"));
    pcSerial.println(F("Bridge not started!"));
    break;

  case EasyVR::BRIDGE_NORMAL:
    // setup EasyVR serial port (low speed)
    port.begin(9600);
    // soft-connect the two serial ports (PC and EasyVR)
    easyvr.bridgeLoop(pcSerial);
    // resume normally if aborted
    pcSerial.println(F("---"));
    pcSerial.println(F("Bridge connection aborted!"));
    break;

  case EasyVR::BRIDGE_BOOT:
    // setup EasyVR serial port (high speed)
    port.begin(115200);
    // soft-connect the two serial ports (PC and EasyVR)
    easyvr.bridgeLoop(pcSerial);
    // resume normally if aborted
    pcSerial.println(F("---"));
    pcSerial.println(F("Bridge connection aborted!"));
    break;
  }

  myservo.attach(9);
  myservo.write(servo_pos*40);

  if (!easyvr.detect())
  {
    Serial.println("EasyVR not detected!");
    for (;;);
  }

  easyvr.setPinOutput(EasyVR::IO1, LOW);
  Serial.print("EasyVR detected, version ");
  Serial.println(easyvr.getID());
}

void loop()
{
  easyvr.detectToken(bits, EasyVR::REJECTION_AVG, 0);
  while (!easyvr.hasFinished());
  idx = easyvr.getToken();
  switch (idx)
  {
  case 1: //move servo up
    Serial.println("Servo up");
    if (servo_pos < 4) servo_pos++;
    break;
  case 2: //move servo down
    Serial.println("Servo down");
    if (servo_pos > 1) servo_pos--;
    break;
  case 3: //LED ON
    Serial.println("LED ON");
    easyvr.setPinOutput(EasyVR::IO1, HIGH);
    break;
  case 4: //LED OFF
    Serial.println("LED OFF");
    easyvr.setPinOutput(EasyVR::IO1, LOW);
    break;
  }
  myservo.write(servo_pos*40);
}



